@@ -313,7 +313,7 @@ def render_table(data, append_headers, append_lineno):
 
 def render_data_to_html(data, append_headers, append_lineno):
     length = 22;
-    data_break = math.ceil(len(data["rows"]) / length)
+    n = math.ceil(len(data["rows"]) / length)
     html = """
     <!DOCTYPE html>
     <html lang="en">
@@ -341,7 +341,7 @@ def render_data_to_html(data, append_headers, append_lineno):
     </html>
     """
     render_paged_table = []
-    for i in data_break:
+    for i in range(0,n):
         render_paged_table.append(render_table(data["rows"][i*length:(i+1)*length], append_headers, append_lineno))
     return html % render_paged_table
 
